@@ -1,12 +1,12 @@
-from oauth2p import utils
+import uuid
+
 from oauth2p.exceptions import UnsupportedGrantType, InvalidClient, InvalidGrant
 
 
 class Authorization(object):
 
-    def __init__(self, storage, token_length=40, expire=3600, refresh_expire=3600):
+    def __init__(self, storage, expire=3600, refresh_expire=3600):
         self.__storage = storage
-        self.__token_length = token_length
         self.__expire = expire
         self.__refresh_expire = refresh_expire
 
@@ -21,10 +21,6 @@ class Authorization(object):
     def token_handlers(self):
         return self.__grant_type_handlers
 
-    @property
-    def token_length(self):
-        return self.__token_length
-
     @property
     def storage(self):
         return self.__storage
@@ -44,7 +40,7 @@ class Authorization(object):
         raise UnsupportedGrantType()
 
     def __client_credentials(self, **kwargs):
-        token = utils.generate_random_vschar(self.token_length)
+        token = str(uuid.uuid1())
         self.storage.save(token=token, token_type='access_token', client_id=None, data=kwargs, expire=self.expire)
 
         return {
@@ -78,10 +74,11 @@ class Authorization(object):
 
         if not username or password is None or not self.storage.is_valid_owner(username, password, **kwargs):
             raise InvalidClient()
-
-        token = utils.generate_random_vschar(self.token_length)
         token_data = kwargs
         token_data['username'] = username
+
+        token = str(uuid.uuid1())
+
         self.storage.save(token=token, token_type='access_token',
                           client_id=client_id, data=token_data, expire=self.expire)
 
@@ -90,7 +87,7 @@ class Authorization(object):
         response['expires_in'] = self.expire
 
         if return_refresh:
-            refresh_token = utils.generate_random_vschar(self.token_length)
+            refresh_token = str(uuid.uuid1())
             self.storage.save(token=refresh_token, token_type='refresh_token',
                               client_id=client_id, data=token_data, expire=self.refresh_expire)
             response['refresh_token'] = refresh_token
@@ -104,7 +101,7 @@ class Authorization(object):
         if not token_data:
             raise InvalidGrant()
 
-        token = utils.generate_random_vschar(self.token_length)
+        token = str(uuid.uuid1())
         self.storage.save(token=token, token_type='access_token', client_id=None, data=kwargs, expire=self.expire)
         return {
             "access_token": token,
